package com.njcn.gather.aireport.clientunit.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.njcn.gather.aireport.clientunit.pojo.param.ClientUnitParam;
import com.njcn.gather.aireport.clientunit.pojo.po.ClientUnitPO;
import com.njcn.gather.aireport.clientunit.pojo.vo.ClientUnitImportResultVO;
import com.njcn.gather.aireport.clientunit.pojo.vo.ClientUnitVO;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

public interface IClientUnitService extends IService<ClientUnitPO> {

    Page<ClientUnitVO> listClientUnits(ClientUnitParam.QueryParam param);

    boolean addClientUnit(ClientUnitParam.AddParam param);

    boolean updateClientUnit(ClientUnitParam.UpdateParam param);

    ClientUnitVO getClientUnit(String id);

    boolean deleteClientUnits(List<String> ids);

    void exportClientUnits(ClientUnitParam.QueryParam param);

    void downloadImportTemplate();

    ClientUnitImportResultVO importClientUnits(MultipartFile file);
}
